Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2010-04-02 01:44:56 +0400
committerCampbell Barton <ideasman42@gmail.com>2010-04-02 01:44:56 +0400
commit9105f6f0bd7f3fe48b624bb516ce16641a115c15 (patch)
treec402417f1a7c281a4569a5ce63fd50e1be8fb9af /release
parent4924654b03cb034291d6f3d523548a5453710ee7 (diff)
rna naming, *_frame --> frame_*
Diffstat (limited to 'release')
-rw-r--r--release/scripts/io/export_fbx.py10
-rw-r--r--release/scripts/io/export_mdd.py8
-rw-r--r--release/scripts/io/export_obj.py8
-rw-r--r--release/scripts/io/import_anim_bvh.py18
-rw-r--r--release/scripts/io/import_shape_mdd.py12
-rw-r--r--release/scripts/io/netrender/client.py10
-rw-r--r--release/scripts/modules/rigify/eye_balls.py4
-rw-r--r--release/scripts/modules/rigify/eye_lid.py40
-rw-r--r--release/scripts/modules/rigify/mouth.py32
-rw-r--r--release/scripts/op/nla.py12
-rw-r--r--release/scripts/op/screen_play_rendered_anim.py4
-rw-r--r--release/scripts/op/sequencer.py14
-rw-r--r--release/scripts/ui/properties_animviz.py8
-rw-r--r--release/scripts/ui/properties_data_armature.py4
-rw-r--r--release/scripts/ui/properties_object_constraint.py4
-rw-r--r--release/scripts/ui/properties_physics_common.py4
-rw-r--r--release/scripts/ui/properties_render.py4
-rw-r--r--release/scripts/ui/space_buttons.py2
-rw-r--r--release/scripts/ui/space_sequencer.py12
-rw-r--r--release/scripts/ui/space_time.py10
-rw-r--r--release/scripts/ui/space_userpref.py10
21 files changed, 115 insertions, 115 deletions
diff --git a/release/scripts/io/export_fbx.py b/release/scripts/io/export_fbx.py
index bc1a0b82d85..a69addf72f5 100644
--- a/release/scripts/io/export_fbx.py
+++ b/release/scripts/io/export_fbx.py
@@ -2041,7 +2041,7 @@ def write(filename, batch_objects = None, \
# ob_base.makeDisplayList()
# This causes the makeDisplayList command to effect the mesh
- scene.set_frame(scene.current_frame)
+ scene.set_frame(scene.frame_current)
# Blender.Set('curframe', Blender.Get('curframe'))
@@ -2216,7 +2216,7 @@ def write(filename, batch_objects = None, \
ob_base.make_display_list()
# ob_base.makeDisplayList()
# This causes the makeDisplayList command to effect the mesh
- scene.set_frame(scene.current_frame)
+ scene.set_frame(scene.frame_current)
# Blender.Set('curframe', Blender.Get('curframe'))
del tmp_ob_type, tmp_objects
@@ -2701,9 +2701,9 @@ Connections: {''')
return int(0.5 + ((t/fps) * 46186158000))
fps = float(render.fps)
- start = scene.start_frame
+ start = scene.frame_start
# start = render.sFrame
- end = scene.end_frame
+ end = scene.frame_end
# end = render.eFrame
if end < start: start, end = end, start
if start==end: ANIM_ENABLE = False
@@ -2713,7 +2713,7 @@ Connections: {''')
if ANIM_ENABLE and [tmp for tmp in ob_anim_lists if tmp]:
- frame_orig = scene.current_frame
+ frame_orig = scene.frame_current
# frame_orig = Blender.Get('curframe')
if ANIM_OPTIMIZE:
diff --git a/release/scripts/io/export_mdd.py b/release/scripts/io/export_mdd.py
index cf72169121c..be3ddbc73bd 100644
--- a/release/scripts/io/export_mdd.py
+++ b/release/scripts/io/export_mdd.py
@@ -82,7 +82,7 @@ def write(filename, sce, ob, PREF_STARTFRAME, PREF_ENDFRAME, PREF_FPS):
bpy.ops.object.mode_set(mode='OBJECT')
- orig_frame = sce.current_frame
+ orig_frame = sce.frame_current
sce.set_frame(PREF_STARTFRAME)
me = ob.create_mesh(True, 'PREVIEW')
@@ -162,8 +162,8 @@ class ExportMDD(bpy.types.Operator):
path = StringProperty(name="File Path", description="File path used for exporting the MDD file", maxlen=1024)
check_existing = BoolProperty(name="Check Existing", description="Check and warn on overwriting existing files", default=True, options={'HIDDEN'})
fps = IntProperty(name="Frames Per Second", description="Number of frames/second", min=minfps, max=maxfps, default=25)
- start_frame = IntProperty(name="Start Frame", description="Start frame for baking", min=minframe, max=maxframe, default=1)
- end_frame = IntProperty(name="End Frame", description="End frame for baking", min=minframe, max=maxframe, default=250)
+ frame_start = IntProperty(name="Start Frame", description="Start frame for baking", min=minframe, max=maxframe, default=1)
+ frame_end = IntProperty(name="End Frame", description="End frame for baking", min=minframe, max=maxframe, default=250)
def poll(self, context):
ob = context.active_object
@@ -173,7 +173,7 @@ class ExportMDD(bpy.types.Operator):
if not self.properties.path:
raise Exception("filename not set")
write(self.properties.path, context.scene, context.active_object,
- self.properties.start_frame, self.properties.end_frame, self.properties.fps)
+ self.properties.frame_start, self.properties.frame_end, self.properties.fps)
return {'FINISHED'}
def invoke(self, context, event):
diff --git a/release/scripts/io/export_obj.py b/release/scripts/io/export_obj.py
index 1f3b8c7db47..6ea00a74435 100644
--- a/release/scripts/io/export_obj.py
+++ b/release/scripts/io/export_obj.py
@@ -839,14 +839,14 @@ def do_export(filename, context,
for scn in export_scenes:
# scn.makeCurrent() # If already current, this is not slow.
# context = scn.getRenderingContext()
- orig_frame = scn.current_frame
+ orig_frame = scn.frame_current
if EXPORT_ALL_SCENES: # Add scene name into the context_name
context_name[1] = '_%s' % bpy.utils.clean_name(scn.name) # WARNING, its possible that this could cause a collision. we could fix if were feeling parranoied.
# Export an animation?
if EXPORT_ANIMATION:
- scene_frames = range(scn.start_frame, context.end_frame+1) # Up to and including the end frame.
+ scene_frames = range(scn.frame_start, context.frame_end + 1) # Up to and including the end frame.
else:
scene_frames = [orig_frame] # Dont export an animation.
@@ -855,7 +855,7 @@ def do_export(filename, context,
if EXPORT_ANIMATION: # Add frame to the filename.
context_name[2] = '_%.6d' % frame
- scn.current_frame = frame
+ scn.frame_current = frame
if EXPORT_SEL_ONLY:
export_objects = context.selected_objects
else:
@@ -874,7 +874,7 @@ def do_export(filename, context,
EXPORT_POLYGROUPS, EXPORT_CURVE_AS_NURBS)
- scn.current_frame = orig_frame
+ scn.frame_current = orig_frame
# Restore old active scene.
# orig_scene.makeCurrent()
diff --git a/release/scripts/io/import_shape_mdd.py b/release/scripts/io/import_shape_mdd.py
index 106645eaa6b..37c99f899b1 100644
--- a/release/scripts/io/import_shape_mdd.py
+++ b/release/scripts/io/import_shape_mdd.py
@@ -55,7 +55,7 @@ def mdd_import(filepath, ob, scene, PREF_START_FRAME=0, PREF_JUMP=1):
basis.name = "Basis"
ob.data.update()
- scene.current_frame = PREF_START_FRAME
+ scene.frame_current = PREF_START_FRAME
def UpdateMesh(ob, fr):
@@ -82,15 +82,15 @@ def mdd_import(filepath, ob, scene, PREF_START_FRAME=0, PREF_JUMP=1):
# insert keyframes
shape_keys = ob.data.shape_keys
- scene.current_frame -= 1
+ scene.frame_current -= 1
ob.data.shape_keys.keys[index].value = 0.0
shape_keys.keys[len(ob.data.shape_keys.keys)-1].keyframe_insert("value")
- scene.current_frame += 1
+ scene.frame_current += 1
ob.data.shape_keys.keys[index].value = 1.0
shape_keys.keys[len(ob.data.shape_keys.keys)-1].keyframe_insert("value")
- scene.current_frame += 1
+ scene.frame_current += 1
ob.data.shape_keys.keys[index].value = 0.0
shape_keys.keys[len(ob.data.shape_keys.keys)-1].keyframe_insert("value")
@@ -120,7 +120,7 @@ class importMDD(bpy.types.Operator):
# to the class instance from the operator settings before calling.
path = StringProperty(name="File Path", description="File path used for importing the MDD file", maxlen=1024)
#fps = IntProperty(name="Frames Per Second", description="Number of frames/second", min=minfps, max=maxfps, default=25)
- start_frame = IntProperty(name="Start Frame", description="Start frame for inserting animation", min=minframe, max=maxframe, default=0)
+ frame_start = IntProperty(name="Start Frame", description="Start frame for inserting animation", min=minframe, max=maxframe, default=0)
def poll(self, context):
@@ -131,7 +131,7 @@ class importMDD(bpy.types.Operator):
if not self.properties.path:
raise Exception("filename not set")
- mdd_import( self.properties.path, bpy.context.active_object, context.scene, self.properties.start_frame, 1)
+ mdd_import( self.properties.path, bpy.context.active_object, context.scene, self.properties.frame_start, 1)
return {'FINISHED'}
diff --git a/release/scripts/io/netrender/client.py b/release/scripts/io/netrender/client.py
index 792a699bfe8..3acc0e1c2e1 100644
--- a/release/scripts/io/netrender/client.py
+++ b/release/scripts/io/netrender/client.py
@@ -96,10 +96,10 @@ def clientSendJob(conn, scene, anim = False):
job = netrender.model.RenderJob()
if anim:
- for f in range(scene.start_frame, scene.end_frame + 1):
+ for f in range(scene.frame_start, scene.frame_end + 1):
job.addFrame(f)
else:
- job.addFrame(scene.current_frame)
+ job.addFrame(scene.frame_current)
filename = bpy.data.filename
job.addFile(filename)
@@ -228,7 +228,7 @@ class NetworkRenderEngine(bpy.types.RenderEngine):
self.update_stats("", "Network render waiting for results")
- requestResult(conn, job_id, scene.current_frame)
+ requestResult(conn, job_id, scene.frame_current)
response = conn.getresponse()
if response.status == http.client.NO_CONTENT:
@@ -236,12 +236,12 @@ class NetworkRenderEngine(bpy.types.RenderEngine):
netsettings.job_id = clientSendJob(conn, scene)
job_id = netsettings.job_id
- requestResult(conn, job_id, scene.current_frame)
+ requestResult(conn, job_id, scene.frame_current)
response = conn.getresponse()
while response.status == http.client.ACCEPTED and not self.test_break():
time.sleep(1)
- requestResult(conn, job_id, scene.current_frame)
+ requestResult(conn, job_id, scene.frame_current)
response = conn.getresponse()
# cancel new jobs (animate on network) on break
diff --git a/release/scripts/modules/rigify/eye_balls.py b/release/scripts/modules/rigify/eye_balls.py
index 9cb3c8229b0..8c126151024 100644
--- a/release/scripts/modules/rigify/eye_balls.py
+++ b/release/scripts/modules/rigify/eye_balls.py
@@ -241,8 +241,8 @@ def control(obj, definitions, base_names, options):
con.subtarget = target_ctrl
con.action = spread_action
con.transform_channel = 'SCALE_X'
- con.start_frame = -20
- con.end_frame = 20
+ con.frame_start = -20
+ con.frame_end = 20
con.minimum = 0.0
con.maximum = 2.0
con.target_space = 'LOCAL'
diff --git a/release/scripts/modules/rigify/eye_lid.py b/release/scripts/modules/rigify/eye_lid.py
index 39804e6b704..6eb1ff87d82 100644
--- a/release/scripts/modules/rigify/eye_lid.py
+++ b/release/scripts/modules/rigify/eye_lid.py
@@ -433,8 +433,8 @@ def control(obj, definitions, base_names, options):
con.subtarget = upper_lid_ctrl
con.action = close_action
con.transform_channel = 'LOCATION_Y'
- con.start_frame = -30
- con.end_frame = 30
+ con.frame_start = -30
+ con.frame_end = 30
con.minimum = -distance*2
con.maximum = distance
con.target_space = 'LOCAL'
@@ -452,8 +452,8 @@ def control(obj, definitions, base_names, options):
con.subtarget = upper_lid_ctrl
con.action = close_action
con.transform_channel = 'LOCATION_Y'
- con.start_frame = -30
- con.end_frame = 30
+ con.frame_start = -30
+ con.frame_end = 30
con.minimum = -distance*2
con.maximum = distance
con.target_space = 'LOCAL'
@@ -470,8 +470,8 @@ def control(obj, definitions, base_names, options):
con.subtarget = upper_lid_ctrl
con.action = close_action
con.transform_channel = 'LOCATION_Y'
- con.start_frame = -30
- con.end_frame = 30
+ con.frame_start = -30
+ con.frame_end = 30
con.minimum = -distance*2
con.maximum = distance
con.target_space = 'LOCAL'
@@ -488,8 +488,8 @@ def control(obj, definitions, base_names, options):
con.subtarget = upper_lid_ctrl
con.action = close_action
con.transform_channel = 'LOCATION_Y'
- con.start_frame = -30
- con.end_frame = 30
+ con.frame_start = -30
+ con.frame_end = 30
con.minimum = -distance*2
con.maximum = distance
con.target_space = 'LOCAL'
@@ -506,8 +506,8 @@ def control(obj, definitions, base_names, options):
con.subtarget = upper_lid_ctrl
con.action = close_action
con.transform_channel = 'LOCATION_Y'
- con.start_frame = -30
- con.end_frame = 30
+ con.frame_start = -30
+ con.frame_end = 30
con.minimum = -distance*2
con.maximum = distance
con.target_space = 'LOCAL'
@@ -525,8 +525,8 @@ def control(obj, definitions, base_names, options):
con.subtarget = lower_lid_ctrl
con.action = close_action
con.transform_channel = 'LOCATION_Y'
- con.start_frame = -30
- con.end_frame = 30
+ con.frame_start = -30
+ con.frame_end = 30
con.minimum = -distance
con.maximum = distance*2
con.target_space = 'LOCAL'
@@ -543,8 +543,8 @@ def control(obj, definitions, base_names, options):
con.subtarget = lower_lid_ctrl
con.action = close_action
con.transform_channel = 'LOCATION_Y'
- con.start_frame = -30
- con.end_frame = 30
+ con.frame_start = -30
+ con.frame_end = 30
con.minimum = -distance
con.maximum = distance*2
con.target_space = 'LOCAL'
@@ -561,8 +561,8 @@ def control(obj, definitions, base_names, options):
con.subtarget = lower_lid_ctrl
con.action = close_action
con.transform_channel = 'LOCATION_Y'
- con.start_frame = -30
- con.end_frame = 30
+ con.frame_start = -30
+ con.frame_end = 30
con.minimum = -distance
con.maximum = distance*2
con.target_space = 'LOCAL'
@@ -579,8 +579,8 @@ def control(obj, definitions, base_names, options):
con.subtarget = lower_lid_ctrl
con.action = close_action
con.transform_channel = 'LOCATION_Y'
- con.start_frame = -30
- con.end_frame = 30
+ con.frame_start = -30
+ con.frame_end = 30
con.minimum = -distance
con.maximum = distance*2
con.target_space = 'LOCAL'
@@ -597,8 +597,8 @@ def control(obj, definitions, base_names, options):
con.subtarget = lower_lid_ctrl
con.action = close_action
con.transform_channel = 'LOCATION_Y'
- con.start_frame = -30
- con.end_frame = 30
+ con.frame_start = -30
+ con.frame_end = 30
con.minimum = -distance
con.maximum = distance*2
con.target_space = 'LOCAL'
diff --git a/release/scripts/modules/rigify/mouth.py b/release/scripts/modules/rigify/mouth.py
index 31d7c5a1ce9..4defd28f56a 100644
--- a/release/scripts/modules/rigify/mouth.py
+++ b/release/scripts/modules/rigify/mouth.py
@@ -543,8 +543,8 @@ def control(obj, definitions, base_names, options):
con.subtarget = jopent
con.action = open_action
con.transform_channel = 'SCALE_Y'
- con.start_frame = 0
- con.end_frame = 60
+ con.frame_start = 0
+ con.frame_end = 60
con.minimum = 0.0
con.maximum = 1.0
con.target_space = 'LOCAL'
@@ -561,8 +561,8 @@ def control(obj, definitions, base_names, options):
con.subtarget = jopent
con.action = open_action
con.transform_channel = 'SCALE_Y'
- con.start_frame = 0
- con.end_frame = 60
+ con.frame_start = 0
+ con.frame_end = 60
con.minimum = 0.0
con.maximum = 1.0
con.target_space = 'LOCAL'
@@ -579,8 +579,8 @@ def control(obj, definitions, base_names, options):
con.subtarget = jopent
con.action = open_action
con.transform_channel = 'SCALE_Y'
- con.start_frame = 0
- con.end_frame = 60
+ con.frame_start = 0
+ con.frame_end = 60
con.minimum = 0.0
con.maximum = 1.0
con.target_space = 'LOCAL'
@@ -597,8 +597,8 @@ def control(obj, definitions, base_names, options):
con.subtarget = jopent
con.action = open_action
con.transform_channel = 'SCALE_Y'
- con.start_frame = 0
- con.end_frame = 60
+ con.frame_start = 0
+ con.frame_end = 60
con.minimum = 0.0
con.maximum = 1.0
con.target_space = 'LOCAL'
@@ -615,8 +615,8 @@ def control(obj, definitions, base_names, options):
con.subtarget = jopent
con.action = open_action
con.transform_channel = 'SCALE_Y'
- con.start_frame = 0
- con.end_frame = 60
+ con.frame_start = 0
+ con.frame_end = 60
con.minimum = 0.0
con.maximum = 1.0
con.target_space = 'LOCAL'
@@ -633,8 +633,8 @@ def control(obj, definitions, base_names, options):
con.subtarget = jopent
con.action = open_action
con.transform_channel = 'SCALE_Y'
- con.start_frame = 0
- con.end_frame = 60
+ con.frame_start = 0
+ con.frame_end = 60
con.minimum = 0.0
con.maximum = 1.0
con.target_space = 'LOCAL'
@@ -651,8 +651,8 @@ def control(obj, definitions, base_names, options):
con.subtarget = jopent
con.action = open_action
con.transform_channel = 'SCALE_Y'
- con.start_frame = 0
- con.end_frame = 60
+ con.frame_start = 0
+ con.frame_end = 60
con.minimum = 0.0
con.maximum = 1.0
con.target_space = 'LOCAL'
@@ -669,8 +669,8 @@ def control(obj, definitions, base_names, options):
con.subtarget = jopent
con.action = open_action
con.transform_channel = 'SCALE_Y'
- con.start_frame = 0
- con.end_frame = 60
+ con.frame_start = 0
+ con.frame_end = 60
con.minimum = 0.0
con.maximum = 1.0
con.target_space = 'LOCAL'
diff --git a/release/scripts/op/nla.py b/release/scripts/op/nla.py
index 99f5ec5cca9..da57bab3748 100644
--- a/release/scripts/op/nla.py
+++ b/release/scripts/op/nla.py
@@ -73,7 +73,7 @@ def pose_info():
return info
-def bake(start_frame, end_frame, step=1, only_selected=False):
+def bake(frame_start, frame_end, step=1, only_selected=False):
# import nla; reload(nla); nla.bake()
scene = bpy.context.scene
@@ -82,7 +82,7 @@ def bake(start_frame, end_frame, step=1, only_selected=False):
info_ls = []
- frame_range = range(start_frame, end_frame + 1, step)
+ frame_range = range(frame_start, frame_end + 1, step)
# could spped this up by applying steps here too...
for f in frame_range:
@@ -103,7 +103,7 @@ def bake(start_frame, end_frame, step=1, only_selected=False):
continue
for f in frame_range:
- matrix = info_ls[int((f-start_frame) / step)][name]["matrix_key"]
+ matrix = info_ls[int((f-frame_start) / step)][name]["matrix_key"]
#pbone.location = matrix.translation_part()
#pbone.rotation_quaternion = matrix.to_quat()
@@ -149,10 +149,10 @@ class BakeAction(bpy.types.Operator):
bl_label = "Bake Action"
bl_options = {'REGISTER', 'UNDO'}
- start_frame = IntProperty(name="Start Frame",
+ frame_start = IntProperty(name="Start Frame",
description="Start frame for baking",
default=1, min=1, max=300000)
- end_frame = IntProperty(name="End Frame",
+ frame_end = IntProperty(name="End Frame",
description="End frame for baking",
default=250, min=1, max=300000)
step = IntProperty(name="Frame Step",
@@ -164,7 +164,7 @@ class BakeAction(bpy.types.Operator):
def execute(self, context):
props = self.properties
- action = bake(props.start_frame, props.end_frame, props.step, props.only_selected)
+ action = bake(props.frame_start, props.frame_end, props.step, props.only_selected)
# basic cleanup, could move elsewhere
for fcu in action.fcurves:
diff --git a/release/scripts/op/screen_play_rendered_anim.py b/release/scripts/op/screen_play_rendered_anim.py
index e809251de7c..b7f75e5b439 100644
--- a/release/scripts/op/screen_play_rendered_anim.py
+++ b/release/scripts/op/screen_play_rendered_anim.py
@@ -103,7 +103,7 @@ class PlayRenderedAnim(bpy.types.Operator):
file = ''.join([(c if file_b[i] == c else "#") for i, c in enumerate(file_a)])
else:
# works for movies and images
- file = rd.frame_path(frame=scene.start_frame)
+ file = rd.frame_path(frame=scene.frame_start)
file = bpy.utils.expandpath(file) # expand '//'
@@ -116,7 +116,7 @@ class PlayRenderedAnim(bpy.types.Operator):
opts = [file, "-playback_speed", str(rd.fps)]
cmd.extend(opts)
elif preset == 'FRAMECYCLER':
- opts = [file, "%d-%d" % (scene.start_frame, scene.end_frame)]
+ opts = [file, "%d-%d" % (scene.frame_start, scene.frame_end)]
cmd.extend(opts)
elif preset == 'RV':
opts = ["-fps", str(rd.fps), "-play", "[ %s ]" % file]
diff --git a/release/scripts/op/sequencer.py b/release/scripts/op/sequencer.py
index 76d5c9cfee9..b3b674cb97e 100644
--- a/release/scripts/op/sequencer.py
+++ b/release/scripts/op/sequencer.py
@@ -49,22 +49,22 @@ class SequencerCrossfadeSounds(bpy.types.Operator):
if seq2 == None:
self.report({'ERROR'}, "Select 2 sound strips.")
return {'CANCELLED'}
- if seq1.start_frame_final > seq2.start_frame_final:
+ if seq1.frame_final_start > seq2.frame_final_start:
s = seq1
seq1 = seq2
seq2 = s
- if seq1.end_frame_final > seq2.start_frame_final:
- tempcfra = context.scene.current_frame
- context.scene.current_frame = seq2.start_frame_final
+ if seq1.frame_final_end > seq2.frame_final_start:
+ tempcfra = context.scene.frame_current
+ context.scene.frame_current = seq2.frame_final_start
seq1.keyframe_insert('volume')
- context.scene.current_frame = seq1.end_frame_final
+ context.scene.frame_current = seq1.frame_final_end
seq1.volume = 0
seq1.keyframe_insert('volume')
seq2.keyframe_insert('volume')
- context.scene.current_frame = seq2.start_frame_final
+ context.scene.frame_current = seq2.frame_final_start
seq2.volume = 0
seq2.keyframe_insert('volume')
- context.scene.current_frame = tempcfra
+ context.scene.frame_current = tempcfra
return {'FINISHED'}
else:
self.report({'ERROR'}, "The selected strips don't overlap.")
diff --git a/release/scripts/ui/properties_animviz.py b/release/scripts/ui/properties_animviz.py
index 15cd80c6fdf..311a8b119cf 100644
--- a/release/scripts/ui/properties_animviz.py
+++ b/release/scripts/ui/properties_animviz.py
@@ -49,8 +49,8 @@ class MotionPathButtonsPanel(bpy.types.Panel):
sub.prop(mps, "before_current", text="Before")
sub.prop(mps, "after_current", text="After")
elif (mps.type == 'RANGE'):
- sub.prop(mps, "start_frame", text="Start")
- sub.prop(mps, "end_frame", text="End")
+ sub.prop(mps, "frame_start", text="Start")
+ sub.prop(mps, "frame_end", text="End")
sub.prop(mps, "frame_step", text="Step")
if bones:
@@ -88,8 +88,8 @@ class OnionSkinButtonsPanel(bpy.types.Panel):
sub = col.column(align=True)
if arm.ghost_type == 'RANGE':
- sub.prop(arm, "ghost_start_frame", text="Start")
- sub.prop(arm, "ghost_end_frame", text="End")
+ sub.prop(arm, "ghost_frame_start", text="Start")
+ sub.prop(arm, "ghost_frame_end", text="End")
sub.prop(arm, "ghost_size", text="Step")
elif arm.ghost_type == 'CURRENT_FRAME':
sub.prop(arm, "ghost_step", text="Range")
diff --git a/release/scripts/ui/properties_data_armature.py b/release/scripts/ui/properties_data_armature.py
index 4f382d550e2..976c2ad78d5 100644
--- a/release/scripts/ui/properties_data_armature.py
+++ b/release/scripts/ui/properties_data_armature.py
@@ -186,8 +186,8 @@ class DATA_PT_ghost(DataButtonsPanel):
sub = col.column(align=True)
if arm.ghost_type == 'RANGE':
- sub.prop(arm, "ghost_start_frame", text="Start")
- sub.prop(arm, "ghost_end_frame", text="End")
+ sub.prop(arm, "ghost_frame_start", text="Start")
+ sub.prop(arm, "ghost_frame_end", text="End")
sub.prop(arm, "ghost_size", text="Step")
elif arm.ghost_type == 'CURRENT_FRAME':
sub.prop(arm, "ghost_step", text="Range")
diff --git a/release/scripts/ui/properties_object_constraint.py b/release/scripts/ui/properties_object_constraint.py
index 47306dd92ac..481da716e02 100644
--- a/release/scripts/ui/properties_object_constraint.py
+++ b/release/scripts/ui/properties_object_constraint.py
@@ -496,8 +496,8 @@ class ConstraintButtonsPanel(bpy.types.Panel):
col = split.column(align=True)
col.label(text="Action Length:")
- col.prop(con, "start_frame", text="Start")
- col.prop(con, "end_frame", text="End")
+ col.prop(con, "frame_start", text="Start")
+ col.prop(con, "frame_end", text="End")
if wide_ui:
col = split.column(align=True)
diff --git a/release/scripts/ui/properties_physics_common.py b/release/scripts/ui/properties_physics_common.py
index 9b24115d492..372509773ef 100644
--- a/release/scripts/ui/properties_physics_common.py
+++ b/release/scripts/ui/properties_physics_common.py
@@ -53,8 +53,8 @@ def point_cache_ui(self, context, cache, enabled, particles, smoke):
if not particles:
row = layout.row()
row.enabled = enabled
- row.prop(cache, "start_frame")
- row.prop(cache, "end_frame")
+ row.prop(cache, "frame_start")
+ row.prop(cache, "frame_end")
row = layout.row()
diff --git a/release/scripts/ui/properties_render.py b/release/scripts/ui/properties_render.py
index c9795d62f71..2d20a948278 100644
--- a/release/scripts/ui/properties_render.py
+++ b/release/scripts/ui/properties_render.py
@@ -532,8 +532,8 @@ class RENDER_PT_dimensions(RenderButtonsPanel):
col = split.column()
sub = col.column(align=True)
sub.label(text="Frame Range:")
- sub.prop(scene, "start_frame", text="Start")
- sub.prop(scene, "end_frame", text="End")
+ sub.prop(scene, "frame_start", text="Start")
+ sub.prop(scene, "frame_end", text="End")
sub.prop(scene, "frame_step", text="Step")
sub.label(text="Frame Rate:")
diff --git a/release/scripts/ui/space_buttons.py b/release/scripts/ui/space_buttons.py
index 019f751449f..9fc30a8189b 100644
--- a/release/scripts/ui/space_buttons.py
+++ b/release/scripts/ui/space_buttons.py
@@ -38,7 +38,7 @@ class Buttons_HT_header(bpy.types.Header):
row = layout.row()
row.prop(so, "buttons_context", expand=True, text="")
- row.prop(scene, "current_frame")
+ row.prop(scene, "frame_current")
class Buttons_MT_view(bpy.types.Menu):
diff --git a/release/scripts/ui/space_sequencer.py b/release/scripts/ui/space_sequencer.py
index 9d7ac872c75..aada58806ad 100644
--- a/release/scripts/ui/space_sequencer.py
+++ b/release/scripts/ui/space_sequencer.py
@@ -347,20 +347,20 @@ class SEQUENCER_PT_edit(SequencerButtonsPanel):
col = layout.column()
col.enabled = not strip.lock
col.prop(strip, "channel")
- col.prop(strip, "start_frame")
+ col.prop(strip, "frame_start")
subrow = col.split(percentage=0.66)
subrow.prop(strip, "length")
subrow.label(text="%.2f sec" % (strip.length / (render.fps / render.fps_base)))
col = layout.column(align=True)
col.label(text="Offset:")
- col.prop(strip, "start_offset", text="Start")
- col.prop(strip, "end_offset", text="End")
+ col.prop(strip, "frame_offset_start", text="Start")
+ col.prop(strip, "frame_offset_end", text="End")
col = layout.column(align=True)
col.label(text="Still:")
- col.prop(strip, "start_still", text="Start")
- col.prop(strip, "end_still", text="End")
+ col.prop(strip, "frame_still_start", text="Start")
+ col.prop(strip, "frame_still_end", text="End")
class SEQUENCER_PT_preview(bpy.types.Panel):
@@ -579,7 +579,7 @@ class SEQUENCER_PT_input_image(SEQUENCER_PT_input):
# Current element for the filename
- elem = strip.getStripElem(context.scene.current_frame)
+ elem = strip.getStripElem(context.scene.frame_current)
if elem:
split = layout.split(percentage=0.2)
col = split.column()
diff --git a/release/scripts/ui/space_time.py b/release/scripts/ui/space_time.py
index cfd5fdfce0b..7417b9659b2 100644
--- a/release/scripts/ui/space_time.py
+++ b/release/scripts/ui/space_time.py
@@ -43,13 +43,13 @@ class TIME_HT_header(bpy.types.Header):
row = layout.row(align=True)
if not scene.use_preview_range:
- row.prop(scene, "start_frame", text="Start")
- row.prop(scene, "end_frame", text="End")
+ row.prop(scene, "frame_start", text="Start")
+ row.prop(scene, "frame_end", text="End")
else:
- row.prop(scene, "preview_range_start_frame", text="Start")
- row.prop(scene, "preview_range_end_frame", text="End")
+ row.prop(scene, "preview_range_frame_start", text="Start")
+ row.prop(scene, "preview_range_frame_end", text="End")
- layout.prop(scene, "current_frame", text="")
+ layout.prop(scene, "frame_current", text="")
layout.separator()
diff --git a/release/scripts/ui/space_userpref.py b/release/scripts/ui/space_userpref.py
index e288b79f152..326a97825d9 100644
--- a/release/scripts/ui/space_userpref.py
+++ b/release/scripts/ui/space_userpref.py
@@ -710,7 +710,7 @@ class USERPREF_PT_theme(bpy.types.Panel):
col.prop(graph, "vertex")
col = split.column()
- col.prop(graph, "current_frame")
+ col.prop(graph, "frame_current")
col.prop(graph, "handle_vertex")
col.prop(graph, "handle_vertex_select")
col.separator()
@@ -757,7 +757,7 @@ class USERPREF_PT_theme(bpy.types.Panel):
col = split.column()
col.prop(nla, "strips")
col.prop(nla, "strips_selected")
- col.prop(nla, "current_frame")
+ col.prop(nla, "frame_current")
elif theme.theme_area == 'DOPESHEET_EDITOR':
dope = theme.dopesheet_editor
@@ -780,7 +780,7 @@ class USERPREF_PT_theme(bpy.types.Panel):
col.prop(dope, "long_key_selected")
col = split.column()
- col.prop(dope, "current_frame")
+ col.prop(dope, "frame_current")
col.prop(dope, "dopesheet_channel")
col.prop(dope, "dopesheet_subchannel")
@@ -827,7 +827,7 @@ class USERPREF_PT_theme(bpy.types.Panel):
col = split.column()
col.prop(seq, "meta_strip")
- col.prop(seq, "current_frame")
+ col.prop(seq, "frame_current")
col.prop(seq, "keyframe")
col.prop(seq, "draw_action")
@@ -886,7 +886,7 @@ class USERPREF_PT_theme(bpy.types.Panel):
col.prop(time, "grid")
col = split.column()
- col.prop(time, "current_frame")
+ col.prop(time, "frame_current")
elif theme.theme_area == 'NODE_EDITOR':
node = theme.node_editor
diff --git a/release/scripts/io/import_anim_bvh.py b/release/scripts/io/import_anim_bvh.py
index 044daf39a47..e6142a2db8a 100644
--- a/release/scripts/io/import_anim_bvh.py
+++ b/release/scripts/io/import_anim_bvh.py
@@ -321,11 +321,11 @@ def bvh_node_dict2objects(context, bvh_nodes, IMPORT_START_FRAME=1, IMPORT_LOOP=
# Animate the data, the last used bvh_node will do since they all have the same number of frames
- for current_frame in range(len(bvh_node.anim_data)):
- Blender.Set('curframe', current_frame + IMPORT_START_FRAME)
+ for frame_current in range(len(bvh_node.anim_data)):
+ Blender.Set('curframe', frame_current + IMPORT_START_FRAME)
for bvh_node in bvh_nodes.values():
- lx, ly, lz, rx, ry, rz = bvh_node.anim_data[current_frame]
+ lx, ly, lz, rx, ry, rz = bvh_node.anim_data[frame_current]
rest_head_local = bvh_node.rest_head_local
bvh_node.temp.loc = rest_head_local + Vector(lx, ly, lz)
@@ -508,16 +508,16 @@ def bvh_node_dict2armature(context, bvh_nodes, ROT_MODE='XYZ', IMPORT_START_FRAM
prev_euler = [Euler() for i in range(len(bvh_nodes))]
# Animate the data, the last used bvh_node will do since they all have the same number of frames
- for current_frame in range(len(bvh_node.anim_data)-1): # skip the first frame (rest frame)
- # print current_frame
+ for frame_current in range(len(bvh_node.anim_data)-1): # skip the first frame (rest frame)
+ # print frame_current
- # if current_frame==40: # debugging
+ # if frame_current==40: # debugging
# break
# Dont neet to set the current frame
for i, bvh_node in enumerate(bvh_nodes.values()):
pose_bone, bone, bone_rest_matrix, bone_rest_matrix_inv = bvh_node.temp
- lx, ly, lz, rx, ry, rz = bvh_node.anim_data[current_frame + 1]
+ lx, ly, lz, rx, ry, rz = bvh_node.anim_data[frame_current + 1]
if bvh_node.has_rot:
bone_rotation_matrix = Euler(rx, ry, rz).to_matrix().resize4x4()
@@ -565,7 +565,7 @@ class BvhImporter(bpy.types.Operator):
path = StringProperty(name="File Path", description="File path used for importing the OBJ file", maxlen=1024, default="")
scale = FloatProperty(name="Scale", description="Scale the BVH by this value", min=0.0001, max=1000000.0, soft_min=0.001, soft_max=100.0, default=0.1)
- start_frame = IntProperty(name="Start Frame", description="Starting frame for the animation", default=1)
+ frame_start = IntProperty(name="Start Frame", description="Starting frame for the animation", default=1)
loop = BoolProperty(name="Loop", description="Loop the animation playback", default=False)
rotate_mode = EnumProperty(items=(
('QUATERNION', "Quaternion", "Convert rotations to quaternions"),
@@ -597,7 +597,7 @@ class BvhImporter(bpy.types.Operator):
bvh_node_dict2armature(context, bvh_nodes,
ROT_MODE=self.properties.rotate_mode,
- IMPORT_START_FRAME=self.properties.start_frame,
+ IMPORT_START_FRAME=self.properties.frame_start,
IMPORT_LOOP=self.properties.loop)
print('Done in %.4f\n' % (time.time() - t1))